@@ -14,7 +14,10 @@ class JSONEncoder(json.JSONEncoder):
         if isinstance(obj, datetime):
             return obj.strftime('%Y-%m-%d %H:%M:%S')
         if isinstance(obj, bytes):
-            return obj.decode('utf8')
+            try:
+                return obj.decode('utf8')
+            except Exception:
+                return str(obj)
         base_type = (str, int, float, dict, list)
         if (not isinstance(obj, base_type) and
                 hasattr(obj, '__str__')):
